@@ -16,16 +16,28 @@
  * Authored by: Jussi Pakkanen <jussi.pakkanen@canonical.com>
  */
 
-#ifndef HTTPDOWNLOADER_H
-#define HTTPDOWNLOADER_H
+#pragma once
 
-#include<string>
+#include <string>
 
-class HttpDownloader {
+namespace unity
+{
+
+namespace thumbnailer
+{
+
+namespace internal
+{
+
+class HttpDownloader
+{
 public:
-    virtual std::string download(const std::string &url) = 0;
-    virtual ~HttpDownloader() {};
+    virtual std::string download(const std::string& url) = 0;
+    virtual ~HttpDownloader(){};
 };
 
+}  // namespace internal
 
-#endif
+}  // namespace thumbnailer
+
+}  // namespace unity
